@@ -14,6 +14,7 @@ from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.pivot import PivotStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
 from mitosheet.step_performers.sort import SortStepPerformer
+from mitosheet.step_performers.set_cell_value import SetCellValueStepPerformer
 from mitosheet.step_performers.column_steps.reorder_column import ReorderColumnStepPerformer
 from mitosheet.step_performers.column_steps.add_column import AddColumnStepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
@@ -25,6 +26,7 @@ from mitosheet.step_performers.import_steps.simple_import import SimpleImportSte
 from mitosheet.step_performers.dataframe_steps.dataframe_delete import DataframeDeleteStepPerformer
 from mitosheet.step_performers.dataframe_steps.dataframe_duplicate import DataframeDuplicateStepPerformer
 from mitosheet.step_performers.dataframe_steps.dataframe_rename import DataframeRenameStepPerformer
+from mitosheet.step_performers.bulk_old_rename.bulk_old_rename import BulkOldRenameStepPerformer
 
 # All steps must be listed in this variable.
 STEP_PERFORMERS: List[StepPerformer] = [
@@ -32,6 +34,7 @@ STEP_PERFORMERS: List[StepPerformer] = [
     ReorderColumnStepPerformer,
     FilterStepPerformer,
     SortStepPerformer,
+    SetCellValueStepPerformer,
     AddColumnStepPerformer,
     SetColumnFormulaStepPerformer,
     ChangeColumnDtypeStepPerformer,
@@ -42,6 +45,7 @@ STEP_PERFORMERS: List[StepPerformer] = [
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
+    BulkOldRenameStepPerformer
 ]
 
 # A helpful mapping for looking up steps based on the incoming events
