@@ -14,7 +14,7 @@ from mitosheet.state import State
 from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
 from mitosheet.updates import UPDATES
-from mitosheet.preprocessing import PREPROCESS_STEPS
+from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
 from mitosheet.utils import dfs_to_json, get_new_id
 from mitosheet.transpiler.transpile import transpile
 from mitosheet.user import get_user_field
@@ -135,8 +135,11 @@ class StepsManager():
         ]
 
         # Then, we go through the process of actually preprocessing the args
-        for PREPROCESS_STEP in PREPROCESS_STEPS:
-            args = PREPROCESS_STEP['execute'](args)
+        # saving any data that we need to transpilate it later this
+        self.preprocess_execution_data = {}
+        for preprocess_step_performers in PREPROCESS_STEP_PERFORMERS:
+            args, execution_data = preprocess_step_performers.execute(args)
+            self.preprocess_execution_data[preprocess_step_performers.preprocess_step_type()] = execution_data
 
         # Then we initialize the analysis with just a simple initialize step
         self.steps: List[Step] = [
@@ -218,7 +221,7 @@ class StepsManager():
         for speed reasons. This results in way less data getting 
         passed around
         """
-        return dfs_to_json(self.curr_step.dfs)
+        return dfs_to_json(self.curr_step.dfs, self.curr_step.column_ids)
     
     @property
     def df_shape_json(self) -> str:
@@ -231,6 +234,25 @@ class StepsManager():
             for df in self.curr_step.dfs
         ])
 
+    @property
+    def column_ids_array_json(self) -> str:
+        """
+        Returns a list of mappings from column ids -> column headers,
+        for each sheet.
+
+        We take special care to return the column ids array in the same order  
+        as the columns in the dataframe itself. 
+        """
+        column_ids_array = []
+        for sheet_index, df in enumerate(self.curr_step.dfs):
+            column_id_to_column_header_map = {
+                self.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header): column_header
+                for column_header in df.keys()
+            }
+            column_ids_array.append(column_id_to_column_header_map)
+
+        return json.dumps(column_ids_array)
+
     @property
     def column_spreadsheet_code_json(self) -> str:
         """
